@@ -3,6 +3,8 @@
 
 #[macro_use]
 extern crate static_assertions;
+#[macro_use]
+extern crate elfo_utils;
 
 pub use crate::{
     actor::ActorStatus,
@@ -18,9 +20,6 @@ pub use crate::{
     topology::Topology,
 };
 
-#[macro_use]
-mod utils;
-
 pub mod config;
 pub mod errors;
 pub mod messages;
